@@ -47,10 +47,13 @@ class VideoSettings:
 
     def _get_quality_settings(self):
         if self.hw_accel == "nvidia":
-            # nvenc doesn't support CRF; only CQ and QP modes. QP consistently provides better quality output for the same bitrate on NVENC however, so we're using that
+            # nvenc doesn't support CRF; only CQ and QP modes.
+            # QP consistently provides better quality output for the same bitrate on NVENC however, so we're using that
             output = f" -rc constqp -qp {self.quality}"
             output += " -b:v 0"  # Unless bitrate is set to 0, CQ is mostly ignored
-            # output += f" -rc-lookahead -b_ref_mode middle" # b-frames are disabled by default, and only supported on Turing+ architectures. Need to auto-detect this
+
+            # b-frames are disabled by default, and only supported on Turing+ architectures. Need to auto-detect this
+            # output += f" -rc-lookahead -b_ref_mode middle"
         else:
             output = f" -crf {self.quality}"
         return output
@@ -63,7 +66,7 @@ class VideoSettings:
 
     def _get_stream_settings(self):
         output = " -map 0:v:0"  # Include first video stream
-        output += " -map 0:s"  # Include all subtitle streams
+        output += " -map 0:s?"  # Include all subtitle streams, if they exist
         output += " -c:s copy"
         return output
 
